@@ -13,10 +13,10 @@ __test__=False
 import pyutilib.component.core
 pyutilib.component.core.PluginGlobals.push_env('pyutilib.autotest')
 
-from plugins import *
-import yaml_plugin
-import json_plugin
-from driver import *
-import default_testdriver
+from pyutilib.autotest.plugins import *
+import pyutilib.autotest.yaml_plugin
+import pyutilib.autotest.json_plugin
+from pyutilib.autotest.driver import *
+import pyutilib.autotest.default_testdriver
 
 pyutilib.component.core.PluginGlobals.pop_env()
