@@ -14,53 +14,53 @@ import os
 from os.path import dirname, abspath
 import sys
 import optparse
-import plugins
-from pyutilib.misc import Options
-from pyutilib.component.core import ExtensionPoint, PluginGlobals
-import pyutilib.th as unittest
 import copy
 import types
 import re
+from pyutilib.misc import Options
+from pyutilib.component.core import ExtensionPoint, PluginGlobals
+import pyutilib.th as unittest
+from pyutilib.autotest import plugins
 
 
 def validate_test_config(suite):
     if suite is None:
-        raise IOError, "Empty suite indicates problem processing suite configuration"
+        raise IOError("Empty suite indicates problem processing suite configuration")
     #
     tmp = set(suite.keys())
     if not tmp.issubset(set(['python','solvers','problems','suites', 'driver'])):
-        raise IOError, "Unexpected test sections: "+str(suite.keys())
+        raise IOError("Unexpected test sections: "+str(suite.keys()))
     #
     if 'python' in suite:
         if not type(suite['python']) is list:
-            raise IOError, "Expected list of Python expressions"
+            raise IOError("Expected list of Python expressions")
     #
     if 'solvers' in suite:
         if not type(suite['solvers']) is dict:
-            raise IOError, "Expected dictionary of solvers"
+            raise IOError("Expected dictionary of solvers")
         for key in suite['solvers']:
             if suite['solvers'][key] is None:
                 suite['solvers'][key] = {}
             elif not type(suite['solvers'][key]) is dict:
-                raise IOError, "Expected solvers to have a dictionary of options: %s" % str(suite)
+                raise IOError("Expected solvers to have a dictionary of options: %s" % str(suite))
     #
     if 'problems' in suite:
         if not type(suite['problems']) is dict:
-            raise IOError, "Expected dictionary of problems"
+            raise IOError("Expected dictionary of problems")
         for key in suite['problems']:
             if suite['problems'][key] is None:
                 suite['problems'][key] = {}
             elif not type(suite['problems'][key]) is dict:
-                raise IOError, "Expected problems to have a dictionary of options"
+                raise IOError("Expected problems to have a dictionary of options")
     #
     if 'suites' in suite:
         if not type(suite['suites']) is dict:
-            raise IOError, "Expected dictionary of suites"
+            raise IOError("Expected dictionary of suites")
         for key in suite['suites']:
             if suite['suites'][key] is None:
                 suite['suites'][key] = {}
             elif not type(suite['suites'][key]) is dict:
-                raise IOError, "Expected suites to have a dictionary of options"
+                raise IOError("Expected suites to have a dictionary of options")
 
 
 
@@ -93,7 +93,7 @@ def create_test_suites(filename=None, config=None, _globals=None, options=None):
             ftype = ftype[1:]
         service = ep.service(ftype)
         if service is None:
-            raise IOError, "Unknown file type.  Cannot load test configuration from file '%s'" % filename
+            raise IOError("Unknown file type.  Cannot load test configuration from file '%s'" % filename)
         config = service.load_test_config(filename)
     #service.print_test_config(config)
     validate_test_config(config)
@@ -103,15 +103,16 @@ def create_test_suites(filename=None, config=None, _globals=None, options=None):
     for item in config.get('python',[]):
         try:
             exec(item, _globals)
-        except Exception, err:
-            print "ERROR executing '%s'" % item
-            print "  Exception: %s" % str(err)
+        except Exception:
+            err = sys.exc_info()[1]
+            print("ERROR executing '%s'" % item)
+            print("  Exception: %s" % str(err))
     #
     # Create test driver, which is put in the global namespace
     #
     driver = plugins.TestDriverFactory(config['driver'])
     if driver is None:
-        raise IOError, "Unexpected test driver '%s'" % config['driver']
+        raise IOError("Unexpected test driver '%s'" % config['driver'])
     _globals["test_driver"] = driver
     #
     # Generate suite
@@ -137,7 +138,7 @@ def create_test_suite(suite, config, _globals, options):
     # Create test driver
     #
     if suite in _globals:
-        raise IOError, "Cannot create suite '%s' since there is another symbol with that name in the global namespace!" % suite
+        raise IOError("Cannot create suite '%s' since there is another symbol with that name in the global namespace!" % suite)
     def setUpClassFn(cls):
         options = cls._options[None]
         cls._test_driver.setUpClass(cls,options)
@@ -158,7 +159,6 @@ def create_test_suite(suite, config, _globals, options):
                 tests.append( (solver, problem, {}) )
     #
     for solver, problem, item in tests:
-        #print 'Z', suite, solver, problem
         ##sname = solver
         if options.testname_format is None:
             test_name = solver+"_"+problem
@@ -301,13 +301,13 @@ def run(argv, _globals=None):
     if _options.help:
         parser.print_help()
 
-        print """
+        print("""
 Examples:
   %s                               - run all test suites
   %s MyTestCase.testSomething      - run MyTestCase.testSomething
   %s MyTestCase                    - run all 'test*' test methods
                                                in MyTestCase
-""" % (args[0],args[0],args[0])
+""" % (args[0],args[0],args[0]))
         return
     #
     # If no value for _globals is specified, then we use the current context.
@@ -335,7 +335,7 @@ Examples:
     suites = []
     categories = set()
     for key in _globals.keys():
-        if type(_globals[key]) is types.TypeType and issubclass(_globals[key], unittest.TestCase):
+        if type(_globals[key]) is type and issubclass(_globals[key], unittest.TestCase):
             suites.append(key)
             for c in _globals[key].suite_categories:
                 categories.add(c)
@@ -344,45 +344,45 @@ Examples:
     #
     if _options.help_tests and not _globals is None:
         suite = _globals.get(_options.help_tests, None)
-        if not type(suite) is types.TypeType:
-            print "Test suite '%s' not found!" % str(_options.help_tests)
+        if not type(suite) is type:
+            print("Test suite '%s' not found!" % str(_options.help_tests))
             return cleanup(_globals, suites)
         tests = []
         for item in dir(suite):
             if item.startswith('test'):
                 tests.append(item)
-        print ""
+        print("")
         if len(tests) > 0:
-            print "Tests defined in test suite '%s':" % _options.help_tests
+            print("Tests defined in test suite '%s':" % _options.help_tests)
             for tmp in sorted(tests):
-                print "    "+tmp
+                print("    "+tmp)
         else:
-            print "No tests defined in test suite '%s':" % _options.help_tests
-        print ""
+            print("No tests defined in test suite '%s':" % _options.help_tests)
+        print("")
         return cleanup(_globals, suites)
     #
     # Process the --help-suites and --help-categories options
     #
     if (_options.help_suites or _options.help_categories) and not _globals is None:
         if _options.help_suites:
-            print ""
+            print("")
             if len(suites) > 0:
-                print "Test suites defined in '%s':" % os.path.basename(argv[0])
+                print("Test suites defined in '%s':" % os.path.basename(argv[0]))
                 for suite in sorted(suites):
-                    print "    "+suite
+                    print("    "+suite)
             else:
-                print "No test suites defined in '%s'!" % os.path.basename(argv[0])
-            print ""
+                print("No test suites defined in '%s'!" % os.path.basename(argv[0]))
+            print("")
         if _options.help_categories:
             tmp = list(categories)
-            print ""
+            print("")
             if len(tmp) > 0:
-                print "Test suite categories defined in '%s':" % os.path.basename(argv[0])
+                print("Test suite categories defined in '%s':" % os.path.basename(argv[0]))
                 for c in sorted(tmp):
-                    print "    "+c
+                    print("    "+c)
             else:
-                print "No test suite categories defined in '%s':" % os.path.basename(argv[0])
-            print ""
+                print("No test suite categories defined in '%s':" % os.path.basename(argv[0]))
+            print("")
         return cleanup(_globals, suites)
     #
     # Reset the value of sys.argv per the expectations of the unittest module
